pub struct PaymentRemittanceInfo {
pub derivation_prefix: String,
pub derivation_suffix: String,
pub sender_identity_key: String,
}Expand description
Remittance output describing how a payment was routed to a recipient.
Carries the derivation keys needed to prove the counterparty can redeem.
Fields
derivation_prefix: Stringderivation_suffix: Stringsender_identity_key: StringTrait Implementations
Sourceimpl Clone for PaymentRemittanceInfo
impl Clone for PaymentRemittanceInfo
Sourcefn clone(&self) -> PaymentRemittanceInfo
fn clone(&self) -> PaymentRemittanceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentRemittanceInfo
impl Debug for PaymentRemittanceInfo
Sourceimpl<'de> Deserialize<'de> for PaymentRemittanceInfo
impl<'de> Deserialize<'de> for PaymentRemittanceInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more