pub struct RegisteredDevice {
pub id: Option<i64>,
pub device_id: Option<String>,
pub platform: Option<String>,
pub fcm_token: String,
pub active: Option<bool>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub last_used: Option<String>,
}Expand description
A registered device record as returned by the server’s /devices endpoint.
All fields are Option because the server may omit any of them.
Includes ALL known server fields to prevent deserialization failures
against go-messagebox-server.
Fields
id: Option<i64>device_id: Option<String>platform: Option<String>fcm_token: Stringactive: Option<bool>created_at: Option<String>updated_at: Option<String>last_used: Option<String>Trait Implementations
Sourceimpl Clone for RegisteredDevice
impl Clone for RegisteredDevice
Sourcefn clone(&self) -> RegisteredDevice
fn clone(&self) -> RegisteredDevice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisteredDevice
impl Debug for RegisteredDevice
Sourceimpl<'de> Deserialize<'de> for RegisteredDevice
impl<'de> Deserialize<'de> for RegisteredDevice
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more